#---------------------------------------------------------------------------
# Copyright IBM Corp. 2011
# All Rights Reserved
#---------------------------------------------------------------------------
################################################################################
# File name:    system/install/lib/PT/Install/Condition/IsFsExtendAllowed.pm
# Description: 	Check if it is possible to extend FS
# Author:       Joris Mihaeli
################################################################################

################################################################################
# Class name:   PT::Install::Condition::IsFsExtendAllowed
# Description: 	Check if it is possible to extend FS class 
# Base class:   PT::Install::Condition
################################################################################
package PT::Install::Condition::IsFsExtendAllowed;

#pragmas
use strict;
use English;
use warnings;

use base qw(PT::Install::Condition);


use PT::Logger;
use PT::Status;
use PT::Install::BaseDefs;
use PT::Install::Params::Name;
use PT::System::Common;


################################################################################
# Name:        new
# Description: constructor
# Params:      void
# Return:      reference to the created instance
################################################################################
sub new 
{
   my $class = shift;
   my $self = bless {}, $class;
   WriteLog(LOG_DEBUG, "enter method(@_)");
   $self->{STATUS} = PT::Status->new();
   return $self;
}
################################################################################
# Name:        init
# Description: initiator of object
# Params:      get the following parameters:
# Return:      status object
################################################################################
sub init 
{
   my $self = shift;
   WriteLog(LOG_DEBUG, "init()");
   $self->{STATUS}->init();
   return true;
}
################################################################################
# Name:        check
# Description: check condition
# Params:      File system name, new device size
# Return:      true/false
################################################################################
sub check 
{
   my $self = shift;
   my ($paramContainerRef) = @_;
   WriteLog(LOG_DEBUG, "check(".ref(@_).")");
   my $status = PT::Status->new();
   $status->errno(ERROR);   # to start with
   # get input parameters
   my ($fs_name, $size);
   eval { $fs_name = $$paramContainerRef->getParam('fsname')->getValue(); };
   if (not defined $fs_name) {
      WriteLog (LOG_ERR, "Failed to get the file system parameter");
      return $status;
   }
   eval { $size = $$paramContainerRef->getParam('size')->getValue(); };
   if (not defined $size) {
      WriteLog (LOG_ERR, "Failed to get the size parameter");
      return $status;
   }
   #starting in redhat 5.11 we need to take only the vg part of the fs_name
   $fs_name = (split("-",$fs_name))[0]; 
   # get the current fs size
   my $cmd = "pvs -o pv_name,vg_name,dev_size --noheadings --separator : --all";
   $cmd .= " --units m 2>/dev/null | grep $fs_name";
   my $command = PT::System::Command->new();
   $status = $command->run($cmd);
   if (OK == $status) {
      my $fs_entry = $command->stdout(); # as: /dev/mapper/vg2-lv_vg2:1020.00M
      chomp($fs_entry);
      my ($mpath,$fs, $fs_size) = split /:/, $fs_entry;
      my $last_char = chop($fs_size);  # chop the 'M' char
      if ($fs_size + $size <= SIZE100T) {
         my $expandStatus = true;
         # Add to the container
         my $expandParam = PT::Install::Params::Name->new(name => 'expand');
         $expandParam->init();
         $expandParam->setValue($expandStatus);
         if ( ! $$paramContainerRef->addParam($expandParam) ) {
            $status->errno(ERROR);
            $status->message('Fail to add parameter');
            return $status;
         }
      }
   } else {
      WriteLog (LOG_ERR, "Failed to get file size". $command->stderr());
   }
       
   return $status;
}

1;
